==> nextcloud-27.1.5.tgz: nextcloud/apps/updatenotification/l10n/he.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} זמינה. ניתן לקבל מידע נוסף על איך לעדכן.",
    "Channel updated" : "הערוץ התעדכן",
    "Update notifications" : "עדכון דיווחים",
    "The update server could not be reached since %d days to check for new updates." : "לא ניתן לגשת אל שרת העדכון מזה %d ימים כדי לבדוק אם יש עדכונים חדשים.",
    "Please check the Nextcloud and server log files for errors." : "נא לחפש שגיאות בקובצי היומן של Nextcloud ושל השרת.",
    "Update to %1$s is available." : "קיים עדכון ל־%1$s.",
    "Update for {app} to version %s is available." : "קיים עדכון עבור {app} לגרסה %s.",
    "Update notification" : "התראה על עדכון",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "מציג התראות עדכון ל־Nextcloud ומספק SSO (גישה אחודה) למעדכן.",
    "Update" : "עדכון",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "הגרסה שפועלת אצלך אינה מתוחזקת יותר. נא לוודא לעדכן לגרסה נתמכת במהירות האפשרית.",
    "View in store" : "הצגה בחנות",
    "Open updater" : "פתיחת המעדכן",
    "Download now" : "להוריד כעת",
    "What's new?" : "מה חדש?",
    "View changelog" : "הצגת יומן שינויים",
    "The update check is not yet finished. Please refresh the page." : "בדיקת העדכונים לא הסתיימה עדיין. נא לעדכן את העמוד.",
    "Your version is up to date." : "הגרסה שבידך מעודכנת.",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "תמיד ניתן לעדכן לגרסה חדשה יותר. אך אי אפשר לשנמך לגרסה יציבה יותר.",
    "Notify members of the following groups about available updates:" : "דיווח למשתמשים של קבוצות אלו על עדכונים זמינים:",
    "The selected update channel does not support updates of the server." : "ערוץ העדכון הנבחר לא תומך בעדכון השרת.",
    "A new version is available: <strong>{newVersionString}</strong>" : "גרסה חדשה זמינה: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "נבדק לאחרונה ב־{lastCheckedDate}",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "נא לוודא שב־config.php שלך ה־<samp>appstoreenabled</samp> לא מוגדר ל‏־false.",
    "Stable" : "יציב",
    "Beta" : "בטא",
    "Update channel:" : "עדכון ערוץ:"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-28.0.14.tgz: nextcloud/apps/updatenotification/l10n/he.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} זמינה. ניתן לקבל מידע נוסף על איך לעדכן.",
    "Channel updated" : "הערוץ התעדכן",
    "Update notifications" : "עדכון דיווחים",
    "The update server could not be reached since %d days to check for new updates." : "לא ניתן לגשת אל שרת העדכון מזה %d ימים כדי לבדוק אם יש עדכונים חדשים.",
    "Please check the Nextcloud and server log files for errors." : "נא לחפש שגיאות בקובצי היומן של Nextcloud ושל השרת.",
    "Update to %1$s is available." : "קיים עדכון ל־%1$s.",
    "Update for {app} to version %s is available." : "קיים עדכון עבור {app} לגרסה %s.",
    "Update notification" : "התראה על עדכון",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "מציג התראות עדכון ל־Nextcloud ומספק SSO (גישה אחודה) למעדכן.",
    "Update" : "עדכון",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "הגרסה שפועלת אצלך אינה מתוחזקת יותר. נא לוודא לעדכן לגרסה נתמכת במהירות האפשרית.",
    "View in store" : "הצגה בחנות",
    "Open updater" : "פתיחת המעדכן",
    "Download now" : "להוריד כעת",
    "What's new?" : "מה חדש?",
    "View changelog" : "הצגת יומן שינויים",
    "The update check is not yet finished. Please refresh the page." : "בדיקת העדכונים לא הסתיימה עדיין. נא לעדכן את העמוד.",
    "Your version is up to date." : "הגרסה שבידך מעודכנת.",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "תמיד ניתן לעדכן לגרסה חדשה יותר. אך אי אפשר לשנמך לגרסה יציבה יותר.",
    "Notify members of the following groups about available updates:" : "דיווח למשתמשים של קבוצות אלו על עדכונים זמינים:",
    "The selected update channel does not support updates of the server." : "ערוץ העדכון הנבחר לא תומך בעדכון השרת.",
    "A new version is available: <strong>{newVersionString}</strong>" : "גרסה חדשה זמינה: <strong>{newVersionString}</strong>",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "נא לוודא שב־config.php שלך ה־<samp>appstoreenabled</samp> לא מוגדר ל‏־false.",
    "Stable" : "יציב",
    "Beta" : "בטא",
    "Update channel:" : "עדכון ערוץ:",
    "Checked on {lastCheckedDate}" : "נבדק לאחרונה ב־{lastCheckedDate}"
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
